@@ -13,8 +13,8 @@ from pymodelextractor.utils.time_bound_utilities import timeout
 
 
 class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
-    def __init__(self, max_states, max_query_length, max_seconds_run=None):
-        super().__init__()
+    def __init__(self, comparator, max_states, max_query_length, max_seconds_run=None):
+        super().__init__(comparator)
         self._max_states = max_states
         self._max_query_length = max_query_length
         self._max_seconds_run = max_seconds_run
@@ -29,20 +29,20 @@ class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
             raise NumberOfStatesExceededException
         return super()._perform_equivalence_query(model)
 
-    def run_learning_with_time_bound(self, teacher, partitions, verbose):
+    def run_learning_with_time_bound(self, teacher, verbose):
         try:
             with timeout(self._max_seconds_run):
-                super().learn(teacher, partitions, verbose)
+                super().learn(teacher, verbose)
         except TimeoutError:
             print("Time Bound Reached")
             self._exceded_time_bound = True
 
-    def learn(self, teacher: ProbabilisticTeacher, partitions: int, verbose: bool = False) -> LearningResult:
+    def learn(self, teacher: ProbabilisticTeacher, verbose: bool = False) -> LearningResult:
         try:
             if self._max_seconds_run is not None:
-                self.run_learning_with_time_bound(teacher, partitions, verbose)
+                self.run_learning_with_time_bound(teacher, verbose)
             else:
-                super().learn(teacher, partitions, verbose)
+                super().learn(teacher, verbose)
         except NumberOfStatesExceededException:
             print("NumberOfStatesExceeded")
             self._exceeded_max_states = True
