@@ -21,35 +21,37 @@ from tests.learners_tests.test_bounded_pdfa_lstar_learner import TestBoundedPDFA
 from tests.learners_tests.test_pac_batch_teacher_quant import TestPACBatchTeacherQuant
 from tests.learners_tests.test_pdfa_quantization_n_ary_tree_learner_running_example \
      import TestPDFAQuantizantionNAryTreeLearnerRunningExample
+from tests.learners_tests.test_mm_lstar_learner import TestMMLStarLearner
 
 
 def run():
-    test_classes_to_run = [TestLStarLearner,
-                           TestLStarColLearner,
-                           TestPDFALStarQuantLearner,
-                           TestPDFALStarToleranceLearner,
-                           TestPDFALStarColQuantLearner,
-                           TestPDFALStarColLearner,
-                           TestKearnsVaziraniLearner,
-                           TestLStarLearner,
-                           TestPDFATeachersLStar,
-                           TestPDFATeachersLStarCol,
-                           TestPACBooleanModelTeachers, 
-                           TestBoundedPDFAQuantizantionNAryTreeLearner, 
-                           TestPDFAQuantizantionNAryTreeLearner,
-                           TestBoundedPDFALStarLearner,
-                           TestBoundedLStarLearner,
-                           TestLambdaStarLearnerWithEqualityAlgebra,
-                           TestPDFAQuantizantionNAryTreeLearnerMetrics,
-                           TestPACBatchTeacherQuant,
-                           TestPDFAQuantizantionNAryTreeLearnerRunningExample]
-    loader = TestLoader()
-    suites_list = []
-    for test_class in test_classes_to_run:
+     test_classes_to_run = [TestLStarLearner,
+                              TestLStarColLearner,
+                              TestPDFALStarQuantLearner,
+                              TestPDFALStarToleranceLearner,
+                              TestPDFALStarColQuantLearner,
+                              TestPDFALStarColLearner,
+                              TestKearnsVaziraniLearner,
+                              TestLStarLearner,
+                              TestPDFATeachersLStar,
+                              TestPDFATeachersLStarCol,
+                              TestPACBooleanModelTeachers, 
+                              TestBoundedPDFAQuantizantionNAryTreeLearner, 
+                              TestPDFAQuantizantionNAryTreeLearner,
+                              TestBoundedPDFALStarLearner,
+                              TestBoundedLStarLearner,
+                              TestLambdaStarLearnerWithEqualityAlgebra,
+                              TestPDFAQuantizantionNAryTreeLearnerMetrics,
+                              TestPACBatchTeacherQuant,
+                              TestPDFAQuantizantionNAryTreeLearnerRunningExample,
+                              TestMMLStarLearner]
+     loader = TestLoader()
+     suites_list = []
+     for test_class in test_classes_to_run:
         suite = loader.loadTestsFromTestCase(test_class)
         suites_list.append(suite)
-    meta_suite = TestSuite(suites_list)
-    TextTestRunner().run(meta_suite)
+     meta_suite = TestSuite(suites_list)
+     TextTestRunner().run(meta_suite)
 
 
 if __name__ == '__main__':
